@@ -12,10 +12,12 @@
 import logging
 import pathlib
 import sys
+import traceback
 import typing
 
 import click
 
+from build_harness._logging import LoggingState
 from build_harness._utility import report_console_error
 from build_harness._version import acquire_version
 from build_harness.tools.git import (
@@ -31,7 +33,6 @@ from ._declarations import (
     DEFAULT_FILE_LOGGING_DISABLED,
     DEFAULT_PROJECT_PATH,
 )
-from ._logging import LoggingState
 from ._release_id import InvalidReleaseId, validate_release_id
 from .state import CommandState, ExitState
 
@@ -122,4 +123,7 @@ def release_flow_main(
         message = "Unexpected error. Check log for details."
         log.exception(str(e))
         report_console_error(message)
+        report_console_error(str(e))
+        stack_trace = traceback.format_exc()
+        report_console_error(stack_trace)
         sys.exit(ExitState.UNKNOWN_ERROR.value)
