@@ -14,6 +14,7 @@ import sys
 
 import click
 
+from build_harness._logging import LoggingState
 from build_harness._version import acquire_version
 
 from ._declarations import (
@@ -23,7 +24,6 @@ from ._declarations import (
     DEFAULT_PROJECT_PATH,
     VALID_LOG_LEVELS,
 )
-from ._logging import LoggingState
 from .analysis import static_analysis
 from .bdd import bdd_acceptance_command
 from .bootstrap import bootstrap
