@@ -13,7 +13,7 @@ import dataclasses
 import enum
 import pathlib
 
-from ._logging import LoggingState
+from build_harness._logging import LoggingState
 
 
 @dataclasses.dataclass
