@@ -132,8 +132,6 @@ def package(ctx: click.Context, release_id: typing.Optional[str]) -> None:
             log.error(message)
             report_console_error(message)
             sys.exit(ExitState.PACKAGING_FAILED.value)
-        finally:
-            version_file_path.unlink(missing_ok=True)
     except Exception:
         message = "Unexpected error. Check log for details."
         log.exception(message)
