@@ -9,7 +9,7 @@
 
 """Define flit entry points."""
 
-from .commands import main, release_flow_main
+from .commands import main, publish_flow_main, release_flow_main
 
 
 def build_harness_entry() -> None:
@@ -17,6 +17,11 @@ def build_harness_entry() -> None:
     main()
 
 
+def publish_flow_entry() -> None:
+    """Flit entry point to ``publish-flow`` command CLI argument parsing."""
+    publish_flow_main()
+
+
 def release_flow_entry() -> None:
     """Flit entry point to ``release-flow`` command CLI argument parsing."""
     release_flow_main()
