@@ -23,5 +23,7 @@ class StdIo:
 @contextlib.contextmanager
 def capture_io() -> typing.ContextManager[StdIo]:
     new = StdIo(err=io.StringIO(), out=io.StringIO())
-    with contextlib.redirect_stderr(new.err), contextlib.redirect_stdout(new.out):
+    with contextlib.redirect_stderr(new.err), contextlib.redirect_stdout(
+        new.out
+    ):
         yield new
