@@ -44,7 +44,8 @@ class TestRunBdd:
         mock_result = mocker.create_autospec(subprocess.CompletedProcess)
         mock_result.returncode = 0
         mock_run = mocker.patch(
-            "build_harness.commands.bdd.run_tests.run_command", return_value=mock_result
+            "build_harness.commands.bdd.run_tests.run_command",
+            return_value=mock_result,
         )
 
         _run_bdd(MOCK_VENV_PATH, False, pathlib.Path("some/xml/path"), list())
@@ -66,7 +67,8 @@ class TestRunBdd:
         mock_result = mocker.create_autospec(subprocess.CompletedProcess)
         mock_result.returncode = 0
         mock_run = mocker.patch(
-            "build_harness.commands.bdd.run_tests.run_command", return_value=mock_result
+            "build_harness.commands.bdd.run_tests.run_command",
+            return_value=mock_result,
         )
 
         _run_bdd(MOCK_VENV_PATH, True, pathlib.Path("some/xml/path"), list())
@@ -91,7 +93,8 @@ class TestRunBdd:
         mock_result = mocker.create_autospec(subprocess.CompletedProcess)
         mock_result.returncode = 0
         mock_run = mocker.patch(
-            "build_harness.commands.bdd.run_tests.run_command", return_value=mock_result
+            "build_harness.commands.bdd.run_tests.run_command",
+            return_value=mock_result,
         )
 
         _run_bdd(MOCK_VENV_PATH, True, pathlib.Path("dist/behave"), list())
@@ -116,7 +119,8 @@ class TestRunBdd:
         mock_result = mocker.create_autospec(subprocess.CompletedProcess)
         mock_result.returncode = 0
         mock_run = mocker.patch(
-            "build_harness.commands.bdd.run_tests.run_command", return_value=mock_result
+            "build_harness.commands.bdd.run_tests.run_command",
+            return_value=mock_result,
         )
 
         _run_bdd(
@@ -148,7 +152,8 @@ class TestRunBdd:
 
     def test_enabled_non_dir(self, not_dir_tests):
         with pytest.raises(
-            AcceptanceTestsError, match=r"^JUnit XML location must be a " r"directory"
+            AcceptanceTestsError,
+            match=r"^JUnit XML location must be a " r"directory",
         ):
             _run_bdd(MOCK_VENV_PATH, True, pathlib.Path("dist/behave"), list())
 
@@ -205,7 +210,9 @@ class TestAcceptanceTests:
         build_harness.commands.build_harness_group.sys.argv = [
             str(MOCK_VENV_PATH / "build-harness")
         ]
-        result = click_runner.invoke(main, ["acceptance", "tests", "--junitxml"])
+        result = click_runner.invoke(
+            main, ["acceptance", "tests", "--junitxml"]
+        )
 
         assert result.exit_code == 0
         mock_run.assert_has_calls(
@@ -245,7 +252,13 @@ class TestAcceptanceTests:
         ]
         result = click_runner.invoke(
             main,
-            ["acceptance", "tests", "--junitxml", "--junitxml-dir", expected_dir],
+            [
+                "acceptance",
+                "tests",
+                "--junitxml",
+                "--junitxml-dir",
+                expected_dir,
+            ],
         )
 
         assert result.exit_code == 0
