@@ -13,11 +13,11 @@ import typing
 
 import pytest
 
+from build_harness._logging import LoggingState
 from build_harness.commands._declarations import (
     DEFAULT_LOG_FILE,
     VALID_LOG_LEVELS,
 )
-from build_harness.commands._logging import LoggingState
 from tests.ci.support.captured_io import capture_io
 from tests.ci.support.directory import change_directory
 
