@@ -12,10 +12,9 @@ import subprocess
 import pytest
 from click.testing import CliRunner
 
-import build_harness.commands._logging
+import build_harness._logging
 import build_harness.commands.build_harness_group
 from build_harness.commands import main
-from build_harness.commands._declarations import VALID_LOG_LEVELS
 from tests.ci.support.click_runner import click_runner  # noqa: F401
 
 
@@ -36,10 +35,8 @@ def mock_code_style(mocker):
 
 @pytest.fixture()
 def mock_command_state(mocker):
-    mocker.patch(
-        "build_harness.commands._logging.logging.handlers.RotatingFileHandler"
-    )
-    mocker.patch.object(build_harness.commands._logging.logging, "getLogger")
+    mocker.patch("build_harness._logging.logging.handlers.RotatingFileHandler")
+    mocker.patch.object(build_harness._logging.logging, "getLogger")
     this_command_state = mocker.patch(
         "build_harness.commands.build_harness_group.CommandState"
     )
